@@ -1,7 +1,7 @@
 /**
 SpatialPy is a Python 3 package for simulation of
 spatial deterministic/stochastic reaction-diffusion-advection problems
-Copyright (C) 2019 - 2022 SpatialPy developers.
+Copyright (C) 2019 - 2023 SpatialPy developers.
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU GENERAL PUBLIC LICENSE Version 3 as
@@ -28,7 +28,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <string.h>
 
 //#include "binheap.h"
-#include "output.h"
+#include "output.hpp"
 #include "particle_system.hpp"
 #include "propensities.hpp"
 #include "simulate_rdme.hpp"
